@@ -30,27 +30,31 @@ plot_funds_points <- function(data, var) {
       den = unique(.data$DEN_MUNICIPALITY)
     )
 
-  summarized_data$tot[summarized_data$tot == 0] <- NA
+  # summarized_data$tot[summarized_data$tot == 0] <- NA
   # Create a color scale based on the log-transformed tot variable
   color_scale <- leaflet::colorNumeric(palette = "viridis",
-                                       domain = log(summarized_data$tot))
+                                       domain = log(summarized_data$tot+1))
   suppressWarnings(
-
     # Create a Leaflet map
-    leaflet::leaflet(summarized_data) %>%
+    map <- leaflet::leaflet(summarized_data) %>%
       leaflet::addTiles() %>%
       leaflet::addCircleMarkers(
         lat = ~lat,
         lng = ~lon,
         radius = ~tot^0.3 * 0.1,
-        color = ~color_scale(log(tot)),
+        color = ~color_scale(log(tot+1)),
         popup = ~paste("Municipality:",den,"<br> Amount: Euro ", tot)
       ) %>%
       leaflet::addLegend(
         pal = color_scale,
-        values = ~log(tot),
+        values = ~log(tot+1),
         title = "Amount",
-        opacity = 1
+        opacity = 1,
+        labFormat = leaflet::labelFormat(prefix = "\u20AC", transform =
+                                           function(tot) {
+                                             return(exp(tot) - 1)
+                                           })
       )
   )
+  print(map)
 }
